@@ -3,7 +3,6 @@
 /**
  * Code for displaying language selection
  *
- * @version $Id$
  * @package phpMyAdmin
  */
 if (! defined('PHPMYADMIN')) {
@@ -42,13 +41,10 @@ function PMA_select_language($use_fieldset = FALSE, $show_doc = TRUE) {
     // For non-English, display "Language" with emphasis because it's
     // not a proper word in the current language; we show it to help
     // people recognize the dialog
-    $language_title = $GLOBALS['strLanguage']
-        . ($GLOBALS['strLanguage'] != 'Language' ? ' - <em>Language</em>' : '');
+    $language_title = __('Language')
+        . (__('Language') != 'Language' ? ' - <em>Language</em>' : '');
     if ($show_doc) {
-        $language_title .= ' <a href="./translators.html" target="documentation">' .
-            ($cfg['ReplaceHelpImg']
-                ? '<img class="icon" src="' . $GLOBALS['pmaThemeImage'] . 'b_info.png" width="11" height="11" alt="Info" />'
-                : '(*)') . '</a>';
+        $language_title .= PMA_showDocu('faq7_2');
     }
     if ($use_fieldset) {
         echo '<fieldset><legend xml:lang="en" dir="ltr">' . $language_title . '</legend>';
@@ -62,13 +58,7 @@ function PMA_select_language($use_fieldset = FALSE, $show_doc = TRUE) {
 
     uasort($GLOBALS['available_languages'], 'PMA_language_cmp');
     foreach ($GLOBALS['available_languages'] as $id => $tmplang) {
-        $lang_name = ucfirst(substr(strrchr($tmplang[0], '|'), 1));
-
-        // Include native name if non empty
-        if (!empty($tmplang[3])) {
-            $lang_name = $tmplang[3] . ' - '
-                . $lang_name;
-        }
+        $lang_name = PMA_langName($tmplang);
 
         //Is current one active?
         if ($lang == $id) {
