@@ -3,7 +3,6 @@
 /**
  * URL/hidden inputs generating.
  *
- * @version $Id$
  * @package phpMyAdmin
  */
 
@@ -30,7 +29,6 @@
  *
  * @access  public
  *
- * @author  nijel
  */
 function PMA_generate_common_hidden_inputs($db = '', $table = '', $indent = 0, $skip = array())
 {
@@ -58,10 +56,6 @@ function PMA_generate_common_hidden_inputs($db = '', $table = '', $indent = 0, $
     && ! empty($GLOBALS['lang'])) {
         $params['lang'] = $GLOBALS['lang'];
     }
-    if (empty($_COOKIE['pma_charset'])
-    && ! empty($GLOBALS['convcharset'])) {
-        $params['convcharset'] = $GLOBALS['convcharset'];
-    }
     if (empty($_COOKIE['pma_collation_connection'])
     && ! empty($GLOBALS['collation_connection'])) {
         $params['collation_connection'] = $GLOBALS['collation_connection'];
@@ -146,7 +140,7 @@ function PMA_getHiddenFields($values, $pre = '')
  * // produces with cookies enabled:
  * // script.php?db=mysql&amp;table=rights
  * // with cookies disabled:
- * // script.php?server=1&amp;lang=en-utf-8&amp;db=mysql&amp;table=rights
+ * // script.php?server=1&amp;lang=en&amp;db=mysql&amp;table=rights
  *
  * // NEW style
  * $params['myparam'] = 'myvalue';
@@ -157,22 +151,20 @@ function PMA_getHiddenFields($values, $pre = '')
  * // produces with cookies enabled:
  * // script.php?myparam=myvalue&amp;db=mysql&amp;table=rights
  * // with cookies disabled:
- * // script.php?server=1&amp;lang=en-utf-8&amp;myparam=myvalue&amp;db=mysql&amp;table=rights
+ * // script.php?server=1&amp;lang=en&amp;myparam=myvalue&amp;db=mysql&amp;table=rights
  *
  * // note the missing ?
  * echo 'script.php' . PMA_generate_common_url();
  * // produces with cookies enabled:
  * // script.php
  * // with cookies disabled:
- * // script.php?server=1&amp;lang=en-utf-8
+ * // script.php?server=1&amp;lang=en
  * </code>
  *
  * @uses    $GLOBALS['server']
  * @uses    $GLOBALS['cfg']['ServerDefault']
  * @uses    $_COOKIE['pma_lang']
  * @uses    $GLOBALS['lang']
- * @uses    $_COOKIE['pma_charset']
- * @uses    $GLOBALS['convcharset']
  * @uses    $_COOKIE['pma_collation_connection']
  * @uses    $GLOBALS['collation_connection']
  * @uses    $_SESSION[' PMA_token ']
@@ -197,7 +189,6 @@ function PMA_getHiddenFields($values, $pre = '')
  *                    instead of '&amp;' for dividing URL parameters
  * @return  string   string with URL parameters
  * @access  public
- * @author  nijel
  */
 function PMA_generate_common_url()
 {
@@ -251,10 +242,6 @@ function PMA_generate_common_url()
       && ! empty($GLOBALS['lang'])) {
         $params['lang'] = $GLOBALS['lang'];
     }
-    if (empty($_COOKIE['pma_charset'])
-      && ! empty($GLOBALS['convcharset'])) {
-        $params['convcharset'] = $GLOBALS['convcharset'];
-    }
     if (empty($_COOKIE['pma_collation_connection'])
       && ! empty($GLOBALS['collation_connection'])) {
         $params['collation_connection'] = $GLOBALS['collation_connection'];
@@ -289,7 +276,6 @@ function PMA_generate_common_url()
  * @param   string  whether to encode separator or not, currently 'none' or 'html'
  * @return  string  character used for separating url parts usally ; or &
  * @access  public
- * @author  nijel
  */
 function PMA_get_arg_separator($encode = 'none')
 {
