@@ -394,6 +394,7 @@ if (strlen($db)) {
 if (isset($GLOBALS['show_as_php']) || !empty($GLOBALS['validatequery'])) {
     unset($result);
     $num_rows = 0;
+    $unlim_num_rows = 0;
 } else {
     if (isset($_SESSION['profiling']) && PMA_profilingSupported()) {
         PMA_DBI_query('SET PROFILING=1;');
@@ -493,6 +494,7 @@ if (isset($GLOBALS['show_as_php']) || !empty($GLOBALS['validatequery'])) {
 
         if (!$is_group
          && !isset($analyzed_sql[0]['queryflags']['union'])
+         && !isset($analyzed_sql[0]['queryflags']['distinct'])
          && !isset($analyzed_sql[0]['table_ref'][1]['table_name'])
          && (empty($analyzed_sql[0]['where_clause'])
            || $analyzed_sql[0]['where_clause'] == '1 ')
@@ -580,7 +582,7 @@ if (isset($GLOBALS['show_as_php']) || !empty($GLOBALS['validatequery'])) {
 } // end else "didn't ask to see php code"
 
 // No rows returned -> move back to the calling page
-if (0 == $num_rows || $is_affected) {
+if ((0 == $num_rows && 0 == $unlim_num_rows) || $is_affected) {
     if ($is_delete) {
         $message = PMA_Message::deleted_rows($num_rows);
     } elseif ($is_insert) {
